Method: Axlsx.trust_input

Defined in:
lib/axlsx.rb

.trust_inputObject

Instructs the serializer to not try to escape cell value input. This will give you a huge speed bonus, but if you content has <, > or other xml character data the workbook will be invalid and excel will complain.



142
143
144
# File 'lib/axlsx.rb', line 142

def self.trust_input
  @trust_input ||= false
end