Method: Axlsx.validate_angle

Defined in:
lib/axlsx/util/validators.rb

.validate_angle(v) ⇒ Boolean

Requires that the value is between -54000000 and 54000000

Raises:

  • (ArgumentError)

    raised if the value cannot be converted to an integer between the allowed angle values for chart label rotation.



80
81
82
# File 'lib/axlsx/util/validators.rb', line 80

def self.validate_angle(v)
  raise ArgumentError, (ERR_ANGLE % v.inspect) unless (v.to_i >= -5400000 && v.to_i <= 5400000)
end