Class: Axlsx::TableStyleElement

Inherits:
Object
  • Object
show all
Defined in:
lib/axlsx/stylesheet/table_style_element.rb

Overview

Note:

tables and table styles are not supported in this version. This class exists in preparation for that support.

an element of style that belongs to a table style.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ TableStyleElement

creates a new TableStyleElement object

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • type (Symbol)
  • size (Integer)
  • dxfId (Integer)


49
50
51
52
53
# File 'lib/axlsx/stylesheet/table_style_element.rb', line 49

def initialize(options={})
  options.each do |o|
    self.send("#{o[0]}=", o[1]) if self.respond_to? o[0]
  end
end

Instance Attribute Details

#dxfIdInteger

The dxfId this style element points to

Returns:

  • (Integer)


43
44
45
# File 'lib/axlsx/stylesheet/table_style_element.rb', line 43

def dxfId
  @dxfId
end

#sizeInteger

Number of rows or columns used in striping when the type is firstRowStripe, secondRowStripe, firstColumnStripe, or secondColumnStripe.

Returns:

  • (Integer)


39
40
41
# File 'lib/axlsx/stylesheet/table_style_element.rb', line 39

def size
  @size
end

#typeSymbol

The type of style element. The following type are allowed :wholeTable :headerRow :totalRow :firstColumn :lastColumn :firstRowStripe :secondRowStripe :firstColumnStripe :secondColumnStripe :firstHeaderCell :lastHeaderCell :firstTotalCell :lastTotalCell :firstSubtotalColumn :secondSubtotalColumn :thirdSubtotalColumn :firstSubtotalRow :secondSubtotalRow :thirdSubtotalRow :blankRow :firstColumnSubheading :secondColumnSubheading :thirdColumnSubheading :firstRowSubheading :secondRowSubheading :thirdRowSubheading :pageFieldLabels :pageFieldValues

Returns:

  • (Symbol)


35
36
37
# File 'lib/axlsx/stylesheet/table_style_element.rb', line 35

def type
  @type
end

Instance Method Details

#to_xml(xml) ⇒ String

Serializes the table style element

Parameters:

  • xml (Nokogiri::XML::Builder)

    The document builder instance this objects xml will be added to.

Returns:

  • (String)


67
68
69
# File 'lib/axlsx/stylesheet/table_style_element.rb', line 67

def to_xml(xml)
  xml.tableStyleElement self.instance_values
end