Method: Axlsx.validate_time_period_type
- Defined in:
- lib/axlsx/util/validators.rb
.validate_time_period_type(v) ⇒ Object
Requires that the value is one of the ST_TimePeriod types valid time period types are today, yesterday, tomorrow, last7Days, thisMonth, lastMonth, nextMonth, thisWeek, lastWeek, nextWeek
166 167 168 |
# File 'lib/axlsx/util/validators.rb', line 166 def self.validate_time_period_type(v) RestrictionValidator.validate :time_period_type, [:today, :yesterday, :tomorrow, :last7Days, :thisMonth, :lastMonth, :nextMonth, :thisWeek, :lastWeek, :nextWeek], v end |